@@ -27,6 +27,7 @@
 #include <QStringList>
 #include <QDBusReply>
 #include <QString>
+#include <qvariant.h>
 
 #include <KLocale>
 
@@ -92,7 +93,14 @@ int Mixer_MPRIS2::mediaControl(QString applicationId, QString commandName)
 	if ( mad == 0 )
 	  return 0; // Might have disconnected recently => simply ignore command
 	
-	QDBusMessage msg = mad->playerIfc->callWithArgumentList(QDBus::NoBlock, commandName, arg);
+//	QDBusMessage msg = mad->playerIfc->callWithArgumentList(QDBus::NoBlock, commandName, arg);
+
+	QDBusPendingReply<QVariant > repl2 = mad->playerIfc->asyncCall(commandName);
+	repl2.waitForFinished();
+	QDBusMessage msg = repl2.reply();
+
+
+
 	if ( msg.type() == QDBusMessage::ErrorMessage )
 	{
 		kError(67100) << "ERROR SET " << applicationId << ": " << msg;
@@ -110,7 +118,16 @@ int Mixer_MPRIS2::readVolumeFromHW( const QString& id, shared_ptr<MixDevice> md)
 	arg.append(QString("org.mpris.MediaPlayer2.Player"));
 	arg.append(QString("Volume"));
 	MPrisAppdata* mad = apps.value(id);
-	QDBusMessage msg = mad->propertyIfc->callWithArgumentList(QDBus::Block, "Get", arg);
+//	QDBusMessage msg = mad->propertyIfc->callWithArgumentList(QDBus::Block, "Get", arg);
+
+	QVariant v1 = QVariant(QString("org.mpris.MediaPlayer2.Player"));
+	QVariant v2 = QVariant(QString("Volume"));
+
+	QDBusPendingReply<QVariant > repl2 = mad->propertyIfc->asyncCall("Get", v1, v2);
+	repl2.waitForFinished();
+	QDBusMessage msg = repl2.reply();
+
+
 	if ( msg.type() == QDBusMessage::ReplyMessage )
 	{
 		QList<QVariant> repl = msg.arguments();
@@ -123,6 +140,7 @@ int Mixer_MPRIS2::readVolumeFromHW( const QString& id, shared_ptr<MixDevice> md)
 			volInt = result2.toFloat() *100;
 
 			volumeChangedInternal(md, volInt);
+			kDebug() << "changed vol" << volInt;
 //			kDebug(67100) << "REPLY " << qv.type() << ": " << volInt;
 		}
 		else
@@ -141,11 +159,13 @@ void Mixer_MPRIS2::volumeChanged(MPrisAppdata* mad, double newVolume)
 {
 	shared_ptr<MixDevice> md = m_mixDevices.get(mad->id);
 	int volInt = newVolume *100;
+	kDebug() << "changed" << volInt;
 	volumeChangedInternal(md, volInt);
 }
 
 void Mixer_MPRIS2::volumeChangedInternal(shared_ptr<MixDevice> md, int volumePercentage)
 {
+	kDebug() << "changed i1" << volumePercentage;
 	if ( md->isVirtuallyMuted() && volumePercentage == 0)
 	{
 		// Special code path for virtual mute switches. Don't write back the volume if it is muted in the KMix GUI
@@ -156,6 +176,7 @@ void Mixer_MPRIS2::volumeChangedInternal(shared_ptr<MixDevice> md, int volumePer
 	vol.setVolume( Volume::LEFT, volumePercentage);
 	md->setMuted(volumePercentage == 0);
 	emit controlChanged();
+	kDebug() << "changed i2" << volumePercentage;
 	//  md->playbackVolume().setVolume(vol);
 }
 
@@ -188,7 +209,19 @@ int Mixer_MPRIS2::writeVolumeToHW( const QString& id, shared_ptr<MixDevice> md )
 	arg << QVariant::fromValue(QDBusVariant(volFloat));
 
 	MPrisAppdata* mad = apps.value(id);
-	QDBusMessage msg = mad->propertyIfc->callWithArgumentList(QDBus::NoBlock, "Set", arg);
+//	QDBusMessage msg = mad->propertyIfc->callWithArgumentList(QDBus::NoBlock, "Set", arg);
+
+	QVariant v1 = QVariant(QString("org.mpris.MediaPlayer2.Player"));
+	QVariant v2 = QVariant(QString("Volume"));
+	QVariant v3 = QVariant::fromValue(QDBusVariant(volFloat));
+//	QVariant v3 = QVariant(volFloat);
+
+	QDBusPendingReply<QVariant > repl2 = mad->propertyIfc->asyncCall("Set", v1, v2, v3);
+	repl2.waitForFinished();
+	QDBusMessage msg = repl2.reply();
+
+
+
 	if ( msg.type() == QDBusMessage::ErrorMessage )
 	{
 		kError(67100) << "ERROR SET " << id << ": " << msg;
@@ -241,18 +274,34 @@ int Mixer_MPRIS2::addAllRunningPlayersAndInitHotplug()
 	 * There is no simple solution (reversing could have the problem of not-adding), so we live for now with it.
 	 */
 	 
-	QDBusReply<QStringList> repl = dbusConn.interface()->registeredServiceNames();
+	/*
+	 * Bug 311189: Introspecting via "dbusConn.interface()->registeredServiceNames()" does not work too well in
+	 *   specific scenarios. Thus I now do a hand crafted 3-line asynchronous version of registeredServiceNames().
+	 */
+	QDBusInterface dbusIfc("org.freedesktop.DBus", "/org/freedesktop/DBus",
+	                          "org.freedesktop.DBus", dbusConn);
+	QDBusPendingReply<QStringList> repl = dbusIfc.asyncCall("ListNames");
+	repl.waitForFinished();
+
 
 	if ( repl.isValid() )
 	{
+		qDebug() << "Attaching Media Players";
 		QStringList result = repl.value();
 		QString s;
 		foreach ( s , result )
 		{
 			if ( s.startsWith("org.mpris.MediaPlayer2") )
+			{
 				addMprisControl(dbusConn, s);
+				kDebug() << "Attached " << s;
+			}
 		}
 	}
+	else
+	{
+		kError() << "Invalid reply while listing Media Players" << repl.error();
+	}
 
 
 	return 0;
@@ -260,6 +309,24 @@ int Mixer_MPRIS2::addAllRunningPlayersAndInitHotplug()
 
 #include <unistd.h>
 
+//QDBusMessage* Mixer_MPRIS2::dbusGetAsyncReply(char method[], QDBusInterface* qdbi)
+//{
+//	const QList<QVariant> arg;
+//	return dbusGetAsyncReply(method, arg, qdbi);
+//}
+//QDBusMessage* Mixer_MPRIS2::dbusGetAsyncReply(const char method[], const QList<QVariant>& arg, QDBusInterface* qdbi)
+//{
+//	QDBusPendingReply<QStringList> repl = qdbi->asyncCallWithArgumentList(method, arg);
+//	repl.waitForFinished();
+//	QDBusMessage msg = repl.reply();
+//	if (! msg.type() == QDBusMessage::ReplyMessage )
+//	{
+//		kWarning() << "Did not receive DBUS reply for method=" << method << "; arg=" << arg;
+//		return 0;
+//	}
+//	return &msg;
+//}
+
 /**
  * Add the MPRIS control designated by the DBUS busDestination
  * to the internal apps list.
@@ -275,19 +342,19 @@ void Mixer_MPRIS2::addMprisControl(QDBusConnection& conn, QString busDestination
 	int lastDot = busDestination.lastIndexOf('.');
 	QString id = ( lastDot == -1 ) ? busDestination : busDestination.mid(lastDot+1);
 	kDebug(67100) << "Get control of " << busDestination << "id=" << id;
-	if (id.startsWith("clementine"))
-	{
-		// Bug 311189: Clementine hangs
-        QString text;
-        text =
-            i18n(
-                "Media player '%1' is not compatible with KMix. Integration skipped.",
-                id);
-        // We cannot do GUI stuff in the backend, so lets only log it for now
-//        KMixToolBox::notification("Unsupported Media Player", text);
-        kWarning() << text;
-        return;
-	}
+//	if (id.startsWith("clementine"))
+//	{
+//		// Bug 311189: Clementine hangs
+//        QString text;
+//        text =
+//            i18n(
+//                "Media player '%1' is not compatible with KMix. Integration skipped.",
+//                id);
+//        // We cannot do GUI stuff in the backend, so lets only log it for now
+////        KMixToolBox::notification("Unsupported Media Player", text);
+//        kWarning() << text;
+//        return;
+//	}
 
 
 	QDBusInterface *qdbiProps  = new QDBusInterface(QString(busDestination), QString("/org/mpris/MediaPlayer2"), "org.freedesktop.DBus.Properties", conn, this);
@@ -302,13 +369,51 @@ void Mixer_MPRIS2::addMprisControl(QDBusConnection& conn, QString busDestination
 
 	QString readableName = id;
 
-	if (id != "clementine")
-	{
+	/*
+	 * 	QDBusInterface dbusIfc("org.freedesktop.DBus", "/org/freedesktop/DBus",
+	                          "org.freedesktop.DBus", dbusConn);
+	QDBusPendingReply<QStringList> repl = dbusIfc.asyncCall("ListNames");
+	repl.waitForFinished();
+	 *
+	 */
+
+//	if (id != "clementine")
+//	{
 		QList<QVariant> arg;
 		arg.append(QString("org.mpris.MediaPlayer2"));
 		arg.append(QString("Identity"));
-		QDBusMessage msg = mad->propertyIfc->callWithArgumentList(QDBus::Block, "Get", arg);
 
+		kDebug() << "--- Identity";
+
+		QVariant v1 = QVariant(QString("org.mpris.MediaPlayer2"));
+		QVariant v2 = QVariant(QString("Identity"));
+
+		/*
+		 * WTF: - asyncCall("Get", arg)                          : returns an error message (see below)
+		 *      - asyncCallWithArgumentList("Get", arg)          : returns an error message (see below)
+		 *      - callWithArgumentList(QDBus::Block, "Get", arg) : works
+		 *      - syncCall("Get", v1, v2)                        : works
+		 *
+		 * kmix(13543) Mixer_MPRIS2::addMprisControl: (marok), msg2= QDBusMessage(type=Error, service=":1.44", error name="org.freedesktop.DBus.Error.UnknownMethod", error message="No such method 'Get' in interface 'org.freedesktop.DBus.Properties' at object path '/org/mpris/MediaPlayer2' (signature 'av')", signature="s", contents=("No such method 'Get' in interface 'org.freedesktop.DBus.Properties' at object path '/org/mpris/MediaPlayer2' (signature 'av')") ) , isValid= false , isFinished= true , isError= true
+		 *
+		 * This behavior is total counter-intuitive :-(((
+		 */
+		//QDBusPendingReply<QVariant > repl2 = mad->propertyIfc->asyncCall("Get", arg);
+
+		QDBusPendingReply<QVariant > repl2 = mad->propertyIfc->asyncCall("Get", v1, v2);
+		repl2.waitForFinished();
+		QDBusMessage msg = repl2.reply();
+
+//		QDBusMessage msg = mad->propertyIfc->callWithArgumentList(QDBus::Block, "Get", arg);
+
+		kDebug() << "(marok), msg=" << msg;
+//		kDebug() << "(marok), msg2=" << msg2 << ", isValid=" << repl2.isValid() << ", isFinished=" << repl2.isFinished() << ", isError=" << repl2.isError();
+
+		//char method[] = "Get";
+//		QDBusMessage* msg = dbusGetAsyncReply("Get", arg, mad->propertyIfc);
+
+//		if ( !repl.isError())
+//		{
 		//msg = conn.call(query, QDBus::Block, 5);
 		if ( msg.type() == QDBusMessage::ReplyMessage )
 		{
@@ -328,7 +433,7 @@ void Mixer_MPRIS2::addMprisControl(QDBusConnection& conn, QString busDestination
 		{
 			qWarning() << "Error (" << msg.type() << "): " << msg.errorName() << " " << msg.errorMessage();
 		}
-	}
+//	}
 
 			// TODO This hardcoded application list is a quick hack. It should be generalized.
 			MixDevice::ChannelType ct = MixDevice::APPLICATION_STREAM;
@@ -427,8 +532,8 @@ void MPrisAppdata::volumeChangedIncoming(QString /*ifc*/,QVariantMap msg ,QStrin
 	QMap<QString, QVariant>::iterator v = msg.find("Volume");
 	if (v != msg.end() )
 	{
-//		kDebug(67100) << "volumeChanged incoming: !!!!!!!!!" ;
 		double volDouble = v.value().toDouble();
+		kDebug(67100) << "volumeChanged incoming: vol=" << volDouble;
 		emit volumeChanged( this, volDouble);
 	}
 
