@@ -67,7 +67,10 @@ public:
   virtual void setEnumIdHW(const QString& id, unsigned int);
   virtual unsigned int enumIdHW(const QString& id);
   virtual bool moveStream( const QString& id, const QString& destId );
-  virtual bool needsPolling() { return false; }
+#ifdef __GNUC__
+#warning MPRIS2 currently uses Polling mode. Method needsPolling() must be overwritten again. Polling needs too much CPU.
+#endif
+  //virtual bool needsPolling() { return false; } // TODO cesken
 
   virtual int mediaPlay(QString id);
   virtual int mediaPrev(QString id);
@@ -81,7 +84,9 @@ private:
     int addAllRunningPlayersAndInitHotplug();
     void notifyToReconfigureControls();
     void volumeChangedInternal(shared_ptr<MixDevice> md, int volumePercentage);
-    
+//	static QDBusMessage* dbusGetAsyncReply(char method[], QDBusInterface* mad);
+//	static QDBusMessage* dbusGetAsyncReply(const char method[], const QList<QVariant>& arg, QDBusInterface* mad);
+
   QMap<QString,MPrisAppdata*> apps;
   QString _id;
 };
