@@ -448,7 +448,7 @@ QString& Mixer::udi(){
 }
 
 /**
- * Set the global master, which is shown in the dock area and which is accesible via the
+ * Set the global master, which is shown in the dock area and which is accessible via the
  * DBUS masterVolume() method.
  *
  * The parameters are taken over as-is, this means without checking for validity.
@@ -617,10 +617,10 @@ void Mixer::commitVolumeChange( shared_ptr<MixDevice> md )
       // We also cannot rely on a notification from the driver (SocketNotifier), because
       // nothing has changed, and so there s nothing to notify.
       _mixerBackend->readSetFromHWforceUpdate();
-      kDebug() << "commiting a control with capture volume, that might announce: " << md->id();
+      kDebug() << "committing a control with capture volume, that might announce: " << md->id();
       _mixerBackend->readSetFromHW();
    }
-      kDebug() << "commiting announces the change of: " << md->id();
+      kDebug() << "committing announces the change of: " << md->id();
       // We announce the change we did, so all other parts of KMix can pick up the change
       ControlManager::instance().announce(md->mixer()->id(), ControlChangeType::Volume, QString("Mixer.commitVolumeChange()"));
 }
